RunAppProperties class final

Constructors

RunAppProperties({LoggerConf loggerConf = const LoggerConf(), StaticConf staticConf = const StaticConf()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
loggerConf → LoggerConf
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticConf → StaticConf
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited