StaticConf class final

Constructors

StaticConf({String fileSystemPath = 'app', String defaultDocument = 'index.html', bool onNotFoundPathUseDefaultDocument = true, bool compress = true})
const

Properties

compress → bool
final
defaultDocument → String
final
fileSystemPath → String
final
hashCode → int
The hash code for this object.
no setterinherited
onNotFoundPathUseDefaultDocument → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited